
package com.clustercontrol.ws.jobmanagement;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the com.clustercontrol.ws.jobmanagement package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.clustercontrol.ws.jobmanagement
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link JobFileCheck }
     * 
     */
    public JobFileCheck createJobFileCheck() {
        return new JobFileCheck();
    }

    /**
     * Create an instance of {@link RunInstructionInfo }
     * 
     */
    public RunInstructionInfo createRunInstructionInfo() {
        return new RunInstructionInfo();
    }

    /**
     * Create an instance of {@link JobKick }
     * 
     */
    public JobKick createJobKick() {
        return new JobKick();
    }

    /**
     * Create an instance of {@link RunInfo }
     * 
     */
    public RunInfo createRunInfo() {
        return new RunInfo();
    }

    /**
     * Create an instance of {@link RunResultInfo }
     * 
     */
    public RunResultInfo createRunResultInfo() {
        return new RunResultInfo();
    }

}
